Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GeneratePagination ¶
GeneratePagination generates a footer pagination so the user can navigate through the web app.
- currentPage - actual page
- totalPages - total available pages
- boundaries - how many pages we want to link in the beginning and in the end
- around - how many pages we want to link before and after the actual page
It checks and fixes wrong values. Why? We want to generate anyway in any case. I think we can add error value or log wrong parameters but stay it for future. It returns an array of page numbers and skipped pages "...". Why array? We want to render result in application and style the pagination.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.